#
# spec file for package python-stripe
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-stripe
Version:        7.12.0
Release:        2.5
Summary:        Python bindings for the Stripe API
License:        MIT
URL:            https://github.com/stripe/stripe-python
Source:         https://files.pythonhosted.org/packages/source/s/stripe/stripe-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#stripe/stripe-python#1195
Patch0:         use-sys-executable.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 6.0}
BuildRequires:  %{python_module pytest-mock >= 2.0}
BuildRequires:  %{python_module requests >= 2.20}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing_extensions >= 4.5.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  stripe-mock
Requires:       python-requests >= 2.20
Requires:       python-typing_extensions >= 4.5.0
Conflicts:      python-stripe-api
BuildArch:      noarch
%python_subpackages

%description
Python bindings for the Stripe API.

%prep
%autosetup -p1 -n stripe-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
stripe-mock &
pid=$!
%pytest
kill $pid

%files %{python_files}
%doc CHANGELOG.md README.md examples/
%license LICENSE
%{python_sitelib}/stripe
%{python_sitelib}/stripe-%{version}.dist-info

%changelog
* Fri Jan 19 2024 Steve Kowalik <steven.kowalik@suse.com>
- Drop patch also-skip-streaming.patch:
  * No longer needed.
- Add BuildRequires on new stripe-mock service, and run it during the
  check phase.
* Wed Jan 17 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 7.12.0:
  * Add support for new resource `CustomerSession`
  * Add support for `create` method on resource `CustomerSession`
  * Remove support for values `obligation_inbound`,
    `obligation_payout_failure`, `obligation_payout`, and
    `obligation_reversal_outbound` from enum `BalanceTransaction.type`
  * Remove support for value `obligation` from enum
    `Reporting.ReportRunCreateParams.parameters.reporting_category`
  * Mark defunct and internal methods as deprecated
  * Do not raise a DeprecationWarning in `stripe.app_info`
  * Fix __getattr__ to raise AttributeError rather than returning None.
  * Add missing explicit reexport for `OAuth`, `Webhook`, `WebhookSignature`
  * `stripe.api_version`, `stripe.multipart_data_generator`,
    `stripe.request_metrics` are deprecated.
  * Move resource type exports to stripe.
  * Add support for new resources `Climate.Order`, `Climate.Product`, and
    `Climate.Supplier`
  * Add support for `cancel`, `create`, `list`, `modify`, and `retrieve`
    methods on resource `Order`
  * Add support for `exemption_indicator` on resource class
    `Charge.PaymentMethodDetails.Card.ThreeDSecure`
  * Add support for `Paypal` on `Checkout.Session.PaymentMethodOptions`
  * Add support for Python 3.11/3.12
  * Include `py.typed` and enable type annotations for the package
  * Behavior change: nested json objects will now deserialize into
    instances of specific classes that subclass `StripeObject`.
  * Behavior change: `PromotionCode.restrictions.currency_options` will now
    deserialize into `dict` and not `StripeObject`.
  * This release changes the pinned API version to `2023-10-16`. Please read
    https://stripe.com/docs/upgrades#2023-10-16 and carefully review the API
    changes.
  * Require typing_extensions >= 4.0.0
  * Remove support for Python 2.
  * https://github.com/stripe/stripe-python/wiki/Migration-guide-for-v6 for
    more detailed instructions for 6.0.0+.
  * Dropped support for Python version 3.4 and 3.5.
  * Add `upcoming_lines` method to the `Invoice` resource.
  * Add support for new resource `CustomerCashBalanceTransaction`
  * Fix incorrect handling of additional request parameters
  * Removed deprecated `AlipayAccount`, `BitcoinReceiver`,
    `BitcoinTransaction`, `IssuerFraudRecord`, `Recipient`,
    `RecipientTransfer`, and  `ThreeDSecure` classes.
  * Removed deprecated `Charge.update_dispute` and `Charge.close_dispute`
    methods that were using legacy REST API endpoint.
  * https://github.com/stripe/stripe-python/wiki/Migration-Guide-for-v3
    contains more information for 3.0.0+.
- Add patch use-sys-executable.patch:
  * Use sys.executable when checking exports.
- Add patch also-skip-streaming.patch:
  * Also skip streaming tests.
  * Switch to autosetup and pyproject macros.
* Sat Dec 11 2021 Axel Braun <axel.braun@gmx.de>
- version 2.63.0
  * skip python2
  * API Updates
  * * Add support for new resource ShippingRate
  * * Add support for expire method on resource Checkout.Session
  * * Add support for list_payment_methods method on resource Customer
  * Stop sending raw exception message as part of Stripe user agent.
* Fri Aug 13 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to v2.60.0
  * Add support for list_computed_upfront_line_items method on resource Quote
  * Add support for new Quote API.
  * Add support for new TaxCode API.
  * Add support for Identity VerificationSession and VerificationReport APIs
  * Add support for the Billing Portal Configuration API
* Sat Feb  6 2021 John Vandenberg <jayvdb@gmail.com>
- Add examples to packaged docs
- Update to v2.55.2
  * Fix CA bundle path
- from v2.55.1
  * Fix issue where StripeObjects in lists would not be converted to dicts
  * Start testing Python 3.9
  * Include the examples in the built sources
* Mon Nov 23 2020 John Vandenberg <jayvdb@gmail.com>
- Activate tests on all platforms
- Update to v2.55
* Thu Aug  6 2020 John Vandenberg <jayvdb@gmail.com>
- Activate tests on x86_64
- Update to v2.50
* Sat Jul 25 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v2.49
* Sun May 17 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v2.48
* Tue Apr  7 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v2.45
* Tue Apr  7 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2.23
